# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from generic_camunda_client.api_client import ApiClient
from generic_camunda_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UserApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def available_operations(self, **kwargs):  # noqa: E501
        """Options  # noqa: E501

        The `/user` resource supports two custom `OPTIONS` requests, one for the resource as such and one for individual user instances. The `OPTIONS` request allows checking for the set of available operations that the currently authenticated user can perform on the /user resource. If the user can perform an operation or not may depend on various things, including the user's authorizations to interact with this resource and the internal configuration of the process engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.available_operations(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ResourceOptionsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.available_operations_with_http_info(**kwargs)  # noqa: E501

    def available_operations_with_http_info(self, **kwargs):  # noqa: E501
        """Options  # noqa: E501

        The `/user` resource supports two custom `OPTIONS` requests, one for the resource as such and one for individual user instances. The `OPTIONS` request allows checking for the set of available operations that the currently authenticated user can perform on the /user resource. If the user can perform an operation or not may depend on various things, including the user's authorizations to interact with this resource and the internal configuration of the process engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.available_operations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ResourceOptionsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method available_operations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user', 'OPTIONS',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceOptionsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def available_user_operations(self, id, **kwargs):  # noqa: E501
        """Options  # noqa: E501

        The `/user` resource supports two custom `OPTIONS` requests, one for the resource as such and one for individual user instances. The `OPTIONS` request allows checking for the set of available operations that the currently authenticated user can perform on the /user resource. If the user can perform an operation or not may depend on various things, including the user's authorizations to interact with this resource and the internal configuration of the process engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.available_user_operations(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be deleted. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ResourceOptionsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.available_user_operations_with_http_info(id, **kwargs)  # noqa: E501

    def available_user_operations_with_http_info(self, id, **kwargs):  # noqa: E501
        """Options  # noqa: E501

        The `/user` resource supports two custom `OPTIONS` requests, one for the resource as such and one for individual user instances. The `OPTIONS` request allows checking for the set of available operations that the currently authenticated user can perform on the /user resource. If the user can perform an operation or not may depend on various things, including the user's authorizations to interact with this resource and the internal configuration of the process engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.available_user_operations_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be deleted. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ResourceOptionsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method available_user_operations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `available_user_operations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/{id}', 'OPTIONS',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceOptionsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_user(self, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        Create a new user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserDto user_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_user_with_http_info(**kwargs)  # noqa: E501

    def create_user_with_http_info(self, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        Create a new user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserDto user_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'user_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_dto' in local_var_params:
            body_params = local_var_params['user_dto']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user(self, id, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        Deletes a user by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be deleted. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_user_with_http_info(id, **kwargs)  # noqa: E501

    def delete_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        Deletes a user by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be deleted. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_count(self, **kwargs):  # noqa: E501
        """Get List Count  # noqa: E501

        Queries for the number of deployments that fulfill given parameters. Takes the same parameters as the [Get Users](https://docs.camunda.org/manual/7.14/reference/rest/user/get-query/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Filter by user id
        :param str id_in: Filter by a comma-separated list of user ids.
        :param str first_name: Filter by the first name of the user. Exact match.
        :param str first_name_like: Filter by the first name that the parameter is a substring of.
        :param str last_name: Filter by the last name of the user. Exact match.
        :param str last_name_like: Filter by the last name that the parameter is a substring of.
        :param str email: Filter by the email of the user. Exact match.
        :param str email_like: Filter by the email that the parameter is a substring of.
        :param str member_of_group: Filter for users which are members of the given group.
        :param str member_of_tenant: Filter for users which are members of the given tenant.
        :param str potential_starter: Only select Users that are potential starter for the given process definition.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CountResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_user_count_with_http_info(**kwargs)  # noqa: E501

    def get_user_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get List Count  # noqa: E501

        Queries for the number of deployments that fulfill given parameters. Takes the same parameters as the [Get Users](https://docs.camunda.org/manual/7.14/reference/rest/user/get-query/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Filter by user id
        :param str id_in: Filter by a comma-separated list of user ids.
        :param str first_name: Filter by the first name of the user. Exact match.
        :param str first_name_like: Filter by the first name that the parameter is a substring of.
        :param str last_name: Filter by the last name of the user. Exact match.
        :param str last_name_like: Filter by the last name that the parameter is a substring of.
        :param str email: Filter by the email of the user. Exact match.
        :param str email_like: Filter by the email that the parameter is a substring of.
        :param str member_of_group: Filter for users which are members of the given group.
        :param str member_of_tenant: Filter for users which are members of the given tenant.
        :param str potential_starter: Only select Users that are potential starter for the given process definition.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CountResultDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'id_in',
            'first_name',
            'first_name_like',
            'last_name',
            'last_name_like',
            'email',
            'email_like',
            'member_of_group',
            'member_of_tenant',
            'potential_starter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in local_var_params and local_var_params['id'] is not None:  # noqa: E501
            query_params.append(('id', local_var_params['id']))  # noqa: E501
        if 'id_in' in local_var_params and local_var_params['id_in'] is not None:  # noqa: E501
            query_params.append(('idIn', local_var_params['id_in']))  # noqa: E501
        if 'first_name' in local_var_params and local_var_params['first_name'] is not None:  # noqa: E501
            query_params.append(('firstName', local_var_params['first_name']))  # noqa: E501
        if 'first_name_like' in local_var_params and local_var_params['first_name_like'] is not None:  # noqa: E501
            query_params.append(('firstNameLike', local_var_params['first_name_like']))  # noqa: E501
        if 'last_name' in local_var_params and local_var_params['last_name'] is not None:  # noqa: E501
            query_params.append(('lastName', local_var_params['last_name']))  # noqa: E501
        if 'last_name_like' in local_var_params and local_var_params['last_name_like'] is not None:  # noqa: E501
            query_params.append(('lastNameLike', local_var_params['last_name_like']))  # noqa: E501
        if 'email' in local_var_params and local_var_params['email'] is not None:  # noqa: E501
            query_params.append(('email', local_var_params['email']))  # noqa: E501
        if 'email_like' in local_var_params and local_var_params['email_like'] is not None:  # noqa: E501
            query_params.append(('emailLike', local_var_params['email_like']))  # noqa: E501
        if 'member_of_group' in local_var_params and local_var_params['member_of_group'] is not None:  # noqa: E501
            query_params.append(('memberOfGroup', local_var_params['member_of_group']))  # noqa: E501
        if 'member_of_tenant' in local_var_params and local_var_params['member_of_tenant'] is not None:  # noqa: E501
            query_params.append(('memberOfTenant', local_var_params['member_of_tenant']))  # noqa: E501
        if 'potential_starter' in local_var_params and local_var_params['potential_starter'] is not None:  # noqa: E501
            query_params.append(('potentialStarter', local_var_params['potential_starter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_profile(self, id, **kwargs):  # noqa: E501
        """Get Profile  # noqa: E501

        Retrieves a user's profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_profile(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to retrieve. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[UserProfileDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_user_profile_with_http_info(id, **kwargs)  # noqa: E501

    def get_user_profile_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Profile  # noqa: E501

        Retrieves a user's profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_profile_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to retrieve. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[UserProfileDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_profile" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_user_profile`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/{id}/profile', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserProfileDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users(self, **kwargs):  # noqa: E501
        """Get List  # noqa: E501

        Query for a list of users using a list of parameters. The size of the result set can be retrieved by using the Get User Count method. [Get User Count](https://docs.camunda.org/manual/7.14/reference/rest/user/get-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Filter by user id
        :param str id_in: Filter by a comma-separated list of user ids.
        :param str first_name: Filter by the first name of the user. Exact match.
        :param str first_name_like: Filter by the first name that the parameter is a substring of.
        :param str last_name: Filter by the last name of the user. Exact match.
        :param str last_name_like: Filter by the last name that the parameter is a substring of.
        :param str email: Filter by the email of the user. Exact match.
        :param str email_like: Filter by the email that the parameter is a substring of.
        :param str member_of_group: Filter for users which are members of the given group.
        :param str member_of_tenant: Filter for users which are members of the given tenant.
        :param str potential_starter: Only select Users that are potential starter for the given process definition.
        :param str sort_by: Sort the results lexicographically by a given criterion. Must be used in conjunction with the sortOrder parameter.
        :param str sort_order: Sort the results in a given order. Values may be asc for ascending order or desc for descending order. Must be used in conjunction with the sortBy parameter.
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[UserProfileDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_with_http_info(**kwargs)  # noqa: E501

    def get_users_with_http_info(self, **kwargs):  # noqa: E501
        """Get List  # noqa: E501

        Query for a list of users using a list of parameters. The size of the result set can be retrieved by using the Get User Count method. [Get User Count](https://docs.camunda.org/manual/7.14/reference/rest/user/get-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Filter by user id
        :param str id_in: Filter by a comma-separated list of user ids.
        :param str first_name: Filter by the first name of the user. Exact match.
        :param str first_name_like: Filter by the first name that the parameter is a substring of.
        :param str last_name: Filter by the last name of the user. Exact match.
        :param str last_name_like: Filter by the last name that the parameter is a substring of.
        :param str email: Filter by the email of the user. Exact match.
        :param str email_like: Filter by the email that the parameter is a substring of.
        :param str member_of_group: Filter for users which are members of the given group.
        :param str member_of_tenant: Filter for users which are members of the given tenant.
        :param str potential_starter: Only select Users that are potential starter for the given process definition.
        :param str sort_by: Sort the results lexicographically by a given criterion. Must be used in conjunction with the sortOrder parameter.
        :param str sort_order: Sort the results in a given order. Values may be asc for ascending order or desc for descending order. Must be used in conjunction with the sortBy parameter.
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[UserProfileDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'id_in',
            'first_name',
            'first_name_like',
            'last_name',
            'last_name_like',
            'email',
            'email_like',
            'member_of_group',
            'member_of_tenant',
            'potential_starter',
            'sort_by',
            'sort_order',
            'first_result',
            'max_results'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in local_var_params and local_var_params['id'] is not None:  # noqa: E501
            query_params.append(('id', local_var_params['id']))  # noqa: E501
        if 'id_in' in local_var_params and local_var_params['id_in'] is not None:  # noqa: E501
            query_params.append(('idIn', local_var_params['id_in']))  # noqa: E501
        if 'first_name' in local_var_params and local_var_params['first_name'] is not None:  # noqa: E501
            query_params.append(('firstName', local_var_params['first_name']))  # noqa: E501
        if 'first_name_like' in local_var_params and local_var_params['first_name_like'] is not None:  # noqa: E501
            query_params.append(('firstNameLike', local_var_params['first_name_like']))  # noqa: E501
        if 'last_name' in local_var_params and local_var_params['last_name'] is not None:  # noqa: E501
            query_params.append(('lastName', local_var_params['last_name']))  # noqa: E501
        if 'last_name_like' in local_var_params and local_var_params['last_name_like'] is not None:  # noqa: E501
            query_params.append(('lastNameLike', local_var_params['last_name_like']))  # noqa: E501
        if 'email' in local_var_params and local_var_params['email'] is not None:  # noqa: E501
            query_params.append(('email', local_var_params['email']))  # noqa: E501
        if 'email_like' in local_var_params and local_var_params['email_like'] is not None:  # noqa: E501
            query_params.append(('emailLike', local_var_params['email_like']))  # noqa: E501
        if 'member_of_group' in local_var_params and local_var_params['member_of_group'] is not None:  # noqa: E501
            query_params.append(('memberOfGroup', local_var_params['member_of_group']))  # noqa: E501
        if 'member_of_tenant' in local_var_params and local_var_params['member_of_tenant'] is not None:  # noqa: E501
            query_params.append(('memberOfTenant', local_var_params['member_of_tenant']))  # noqa: E501
        if 'potential_starter' in local_var_params and local_var_params['potential_starter'] is not None:  # noqa: E501
            query_params.append(('potentialStarter', local_var_params['potential_starter']))  # noqa: E501
        if 'sort_by' in local_var_params and local_var_params['sort_by'] is not None:  # noqa: E501
            query_params.append(('sortBy', local_var_params['sort_by']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'first_result' in local_var_params and local_var_params['first_result'] is not None:  # noqa: E501
            query_params.append(('firstResult', local_var_params['first_result']))  # noqa: E501
        if 'max_results' in local_var_params and local_var_params['max_results'] is not None:  # noqa: E501
            query_params.append(('maxResults', local_var_params['max_results']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserProfileDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unlock_user(self, id, **kwargs):  # noqa: E501
        """Unlock User  # noqa: E501

        Unlocks a user by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unlock_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be unlocked. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.unlock_user_with_http_info(id, **kwargs)  # noqa: E501

    def unlock_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """Unlock User  # noqa: E501

        Unlocks a user by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unlock_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be unlocked. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unlock_user" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `unlock_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/{id}/unlock', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_credentials(self, id, password, authenticated_user_password, **kwargs):  # noqa: E501
        """Update Credentials  # noqa: E501

        Updates a user's credentials (password)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_credentials(id, password, authenticated_user_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be updated. (required)
        :param str password: The users new password. (required)
        :param str authenticated_user_password: The password of the authenticated user who changes the password of the user (i.e., the user with passed id as path parameter). (required)
        :param UserCredentialsDto user_credentials_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_credentials_with_http_info(id, password, authenticated_user_password, **kwargs)  # noqa: E501

    def update_credentials_with_http_info(self, id, password, authenticated_user_password, **kwargs):  # noqa: E501
        """Update Credentials  # noqa: E501

        Updates a user's credentials (password)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_credentials_with_http_info(id, password, authenticated_user_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the user to be updated. (required)
        :param str password: The users new password. (required)
        :param str authenticated_user_password: The password of the authenticated user who changes the password of the user (i.e., the user with passed id as path parameter). (required)
        :param UserCredentialsDto user_credentials_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'password',
            'authenticated_user_password',
            'user_credentials_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_credentials" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `update_credentials`")  # noqa: E501
        # verify the required parameter 'password' is set
        if self.api_client.client_side_validation and ('password' not in local_var_params or  # noqa: E501
                                                        local_var_params['password'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `password` when calling `update_credentials`")  # noqa: E501
        # verify the required parameter 'authenticated_user_password' is set
        if self.api_client.client_side_validation and ('authenticated_user_password' not in local_var_params or  # noqa: E501
                                                        local_var_params['authenticated_user_password'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `authenticated_user_password` when calling `update_credentials`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'password' in local_var_params and local_var_params['password'] is not None:  # noqa: E501
            query_params.append(('password', local_var_params['password']))  # noqa: E501
        if 'authenticated_user_password' in local_var_params and local_var_params['authenticated_user_password'] is not None:  # noqa: E501
            query_params.append(('authenticatedUserPassword', local_var_params['authenticated_user_password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_credentials_dto' in local_var_params:
            body_params = local_var_params['user_credentials_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/user/{id}/credentials', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from generic_camunda_client.api_client import ApiClient
from generic_camunda_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class HistoricActivityInstanceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_historic_activity_instance(self, id, **kwargs):  # noqa: E501
        """Get  # noqa: E501

        Retrieves a historic activity instance by id, according to the `HistoricActivityInstance` interface in the engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_historic_activity_instance(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the historic activity instance to be retrieved. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: HistoricActivityInstanceDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_historic_activity_instance_with_http_info(id, **kwargs)  # noqa: E501

    def get_historic_activity_instance_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get  # noqa: E501

        Retrieves a historic activity instance by id, according to the `HistoricActivityInstance` interface in the engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_historic_activity_instance_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the historic activity instance to be retrieved. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(HistoricActivityInstanceDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_historic_activity_instance" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_historic_activity_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/history/activity-instance/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='HistoricActivityInstanceDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_historic_activity_instances(self, **kwargs):  # noqa: E501
        """Get List  # noqa: E501

        Queries for historic activity instances that fulfill the given parameters. The size of the result set can be retrieved by using the [Get Historic Activity Instance Count](https://docs.camunda.org/manual/7.14/reference/rest/history/activity-instance/get-activity-instance-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_historic_activity_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sort_by: Sort the results lexicographically by a given criterion. Must be used in conjunction with the sortOrder parameter.
        :param str sort_order: Sort the results in a given order. Values may be asc for ascending order or desc for descending order. Must be used in conjunction with the sortBy parameter.
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param str activity_instance_id: Filter by activity instance id.
        :param str process_instance_id: Filter by process instance id.
        :param str process_definition_id: Filter by process definition id.
        :param str execution_id: Filter by the id of the execution that executed the activity instance.
        :param str activity_id: Filter by the activity id (according to BPMN 2.0 XML).
        :param str activity_name: Filter by the activity name (according to BPMN 2.0 XML).
        :param str activity_type: Filter by activity type.
        :param str task_assignee: Only include activity instances that are user tasks and assigned to a given user.
        :param bool finished: Only include finished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool unfinished: Only include unfinished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool canceled: Only include canceled activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool complete_scope: Only include activity instances which completed a scope. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param datetime started_before: Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime started_after: Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_before: Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_after: Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str tenant_id_in: Filter by a comma-separated list of ids. An activity instance must have one of the given tenant ids.
        :param bool without_tenant_id: Only include historic activity instances that belong to no tenant. Value may only be `true`, as `false` is the default behavior.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[HistoricActivityInstanceDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_historic_activity_instances_with_http_info(**kwargs)  # noqa: E501

    def get_historic_activity_instances_with_http_info(self, **kwargs):  # noqa: E501
        """Get List  # noqa: E501

        Queries for historic activity instances that fulfill the given parameters. The size of the result set can be retrieved by using the [Get Historic Activity Instance Count](https://docs.camunda.org/manual/7.14/reference/rest/history/activity-instance/get-activity-instance-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_historic_activity_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sort_by: Sort the results lexicographically by a given criterion. Must be used in conjunction with the sortOrder parameter.
        :param str sort_order: Sort the results in a given order. Values may be asc for ascending order or desc for descending order. Must be used in conjunction with the sortBy parameter.
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param str activity_instance_id: Filter by activity instance id.
        :param str process_instance_id: Filter by process instance id.
        :param str process_definition_id: Filter by process definition id.
        :param str execution_id: Filter by the id of the execution that executed the activity instance.
        :param str activity_id: Filter by the activity id (according to BPMN 2.0 XML).
        :param str activity_name: Filter by the activity name (according to BPMN 2.0 XML).
        :param str activity_type: Filter by activity type.
        :param str task_assignee: Only include activity instances that are user tasks and assigned to a given user.
        :param bool finished: Only include finished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool unfinished: Only include unfinished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool canceled: Only include canceled activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool complete_scope: Only include activity instances which completed a scope. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param datetime started_before: Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime started_after: Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_before: Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_after: Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str tenant_id_in: Filter by a comma-separated list of ids. An activity instance must have one of the given tenant ids.
        :param bool without_tenant_id: Only include historic activity instances that belong to no tenant. Value may only be `true`, as `false` is the default behavior.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[HistoricActivityInstanceDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sort_by',
            'sort_order',
            'first_result',
            'max_results',
            'activity_instance_id',
            'process_instance_id',
            'process_definition_id',
            'execution_id',
            'activity_id',
            'activity_name',
            'activity_type',
            'task_assignee',
            'finished',
            'unfinished',
            'canceled',
            'complete_scope',
            'started_before',
            'started_after',
            'finished_before',
            'finished_after',
            'tenant_id_in',
            'without_tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_historic_activity_instances" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sort_by' in local_var_params and local_var_params['sort_by'] is not None:  # noqa: E501
            query_params.append(('sortBy', local_var_params['sort_by']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'first_result' in local_var_params and local_var_params['first_result'] is not None:  # noqa: E501
            query_params.append(('firstResult', local_var_params['first_result']))  # noqa: E501
        if 'max_results' in local_var_params and local_var_params['max_results'] is not None:  # noqa: E501
            query_params.append(('maxResults', local_var_params['max_results']))  # noqa: E501
        if 'activity_instance_id' in local_var_params and local_var_params['activity_instance_id'] is not None:  # noqa: E501
            query_params.append(('activityInstanceId', local_var_params['activity_instance_id']))  # noqa: E501
        if 'process_instance_id' in local_var_params and local_var_params['process_instance_id'] is not None:  # noqa: E501
            query_params.append(('processInstanceId', local_var_params['process_instance_id']))  # noqa: E501
        if 'process_definition_id' in local_var_params and local_var_params['process_definition_id'] is not None:  # noqa: E501
            query_params.append(('processDefinitionId', local_var_params['process_definition_id']))  # noqa: E501
        if 'execution_id' in local_var_params and local_var_params['execution_id'] is not None:  # noqa: E501
            query_params.append(('executionId', local_var_params['execution_id']))  # noqa: E501
        if 'activity_id' in local_var_params and local_var_params['activity_id'] is not None:  # noqa: E501
            query_params.append(('activityId', local_var_params['activity_id']))  # noqa: E501
        if 'activity_name' in local_var_params and local_var_params['activity_name'] is not None:  # noqa: E501
            query_params.append(('activityName', local_var_params['activity_name']))  # noqa: E501
        if 'activity_type' in local_var_params and local_var_params['activity_type'] is not None:  # noqa: E501
            query_params.append(('activityType', local_var_params['activity_type']))  # noqa: E501
        if 'task_assignee' in local_var_params and local_var_params['task_assignee'] is not None:  # noqa: E501
            query_params.append(('taskAssignee', local_var_params['task_assignee']))  # noqa: E501
        if 'finished' in local_var_params and local_var_params['finished'] is not None:  # noqa: E501
            query_params.append(('finished', local_var_params['finished']))  # noqa: E501
        if 'unfinished' in local_var_params and local_var_params['unfinished'] is not None:  # noqa: E501
            query_params.append(('unfinished', local_var_params['unfinished']))  # noqa: E501
        if 'canceled' in local_var_params and local_var_params['canceled'] is not None:  # noqa: E501
            query_params.append(('canceled', local_var_params['canceled']))  # noqa: E501
        if 'complete_scope' in local_var_params and local_var_params['complete_scope'] is not None:  # noqa: E501
            query_params.append(('completeScope', local_var_params['complete_scope']))  # noqa: E501
        if 'started_before' in local_var_params and local_var_params['started_before'] is not None:  # noqa: E501
            query_params.append(('startedBefore', local_var_params['started_before']))  # noqa: E501
        if 'started_after' in local_var_params and local_var_params['started_after'] is not None:  # noqa: E501
            query_params.append(('startedAfter', local_var_params['started_after']))  # noqa: E501
        if 'finished_before' in local_var_params and local_var_params['finished_before'] is not None:  # noqa: E501
            query_params.append(('finishedBefore', local_var_params['finished_before']))  # noqa: E501
        if 'finished_after' in local_var_params and local_var_params['finished_after'] is not None:  # noqa: E501
            query_params.append(('finishedAfter', local_var_params['finished_after']))  # noqa: E501
        if 'tenant_id_in' in local_var_params and local_var_params['tenant_id_in'] is not None:  # noqa: E501
            query_params.append(('tenantIdIn', local_var_params['tenant_id_in']))  # noqa: E501
        if 'without_tenant_id' in local_var_params and local_var_params['without_tenant_id'] is not None:  # noqa: E501
            query_params.append(('withoutTenantId', local_var_params['without_tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/history/activity-instance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[HistoricActivityInstanceDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_historic_activity_instances_count(self, **kwargs):  # noqa: E501
        """Get List Count  # noqa: E501

        Queries for the number of historic activity instances that fulfill the given parameters. Takes the same parameters as the [Get Historic Activity Instance](https://docs.camunda.org/manual/7.14/reference/rest/history/activity-instance/get-activity-instance-query/)  method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_historic_activity_instances_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str activity_instance_id: Filter by activity instance id.
        :param str process_instance_id: Filter by process instance id.
        :param str process_definition_id: Filter by process definition id.
        :param str execution_id: Filter by the id of the execution that executed the activity instance.
        :param str activity_id: Filter by the activity id (according to BPMN 2.0 XML).
        :param str activity_name: Filter by the activity name (according to BPMN 2.0 XML).
        :param str activity_type: Filter by activity type.
        :param str task_assignee: Only include activity instances that are user tasks and assigned to a given user.
        :param bool finished: Only include finished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool unfinished: Only include unfinished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool canceled: Only include canceled activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool complete_scope: Only include activity instances which completed a scope. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param datetime started_before: Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime started_after: Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_before: Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_after: Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str tenant_id_in: Filter by a comma-separated list of ids. An activity instance must have one of the given tenant ids.
        :param bool without_tenant_id: Only include historic activity instances that belong to no tenant. Value may only be `true`, as `false` is the default behavior.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CountResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_historic_activity_instances_count_with_http_info(**kwargs)  # noqa: E501

    def get_historic_activity_instances_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get List Count  # noqa: E501

        Queries for the number of historic activity instances that fulfill the given parameters. Takes the same parameters as the [Get Historic Activity Instance](https://docs.camunda.org/manual/7.14/reference/rest/history/activity-instance/get-activity-instance-query/)  method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_historic_activity_instances_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str activity_instance_id: Filter by activity instance id.
        :param str process_instance_id: Filter by process instance id.
        :param str process_definition_id: Filter by process definition id.
        :param str execution_id: Filter by the id of the execution that executed the activity instance.
        :param str activity_id: Filter by the activity id (according to BPMN 2.0 XML).
        :param str activity_name: Filter by the activity name (according to BPMN 2.0 XML).
        :param str activity_type: Filter by activity type.
        :param str task_assignee: Only include activity instances that are user tasks and assigned to a given user.
        :param bool finished: Only include finished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool unfinished: Only include unfinished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool canceled: Only include canceled activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param bool complete_scope: Only include activity instances which completed a scope. Value may only be `true`, as `false` behaves the same as when the property is not set.
        :param datetime started_before: Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime started_after: Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_before: Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime finished_after: Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str tenant_id_in: Filter by a comma-separated list of ids. An activity instance must have one of the given tenant ids.
        :param bool without_tenant_id: Only include historic activity instances that belong to no tenant. Value may only be `true`, as `false` is the default behavior.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CountResultDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'activity_instance_id',
            'process_instance_id',
            'process_definition_id',
            'execution_id',
            'activity_id',
            'activity_name',
            'activity_type',
            'task_assignee',
            'finished',
            'unfinished',
            'canceled',
            'complete_scope',
            'started_before',
            'started_after',
            'finished_before',
            'finished_after',
            'tenant_id_in',
            'without_tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_historic_activity_instances_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'activity_instance_id' in local_var_params and local_var_params['activity_instance_id'] is not None:  # noqa: E501
            query_params.append(('activityInstanceId', local_var_params['activity_instance_id']))  # noqa: E501
        if 'process_instance_id' in local_var_params and local_var_params['process_instance_id'] is not None:  # noqa: E501
            query_params.append(('processInstanceId', local_var_params['process_instance_id']))  # noqa: E501
        if 'process_definition_id' in local_var_params and local_var_params['process_definition_id'] is not None:  # noqa: E501
            query_params.append(('processDefinitionId', local_var_params['process_definition_id']))  # noqa: E501
        if 'execution_id' in local_var_params and local_var_params['execution_id'] is not None:  # noqa: E501
            query_params.append(('executionId', local_var_params['execution_id']))  # noqa: E501
        if 'activity_id' in local_var_params and local_var_params['activity_id'] is not None:  # noqa: E501
            query_params.append(('activityId', local_var_params['activity_id']))  # noqa: E501
        if 'activity_name' in local_var_params and local_var_params['activity_name'] is not None:  # noqa: E501
            query_params.append(('activityName', local_var_params['activity_name']))  # noqa: E501
        if 'activity_type' in local_var_params and local_var_params['activity_type'] is not None:  # noqa: E501
            query_params.append(('activityType', local_var_params['activity_type']))  # noqa: E501
        if 'task_assignee' in local_var_params and local_var_params['task_assignee'] is not None:  # noqa: E501
            query_params.append(('taskAssignee', local_var_params['task_assignee']))  # noqa: E501
        if 'finished' in local_var_params and local_var_params['finished'] is not None:  # noqa: E501
            query_params.append(('finished', local_var_params['finished']))  # noqa: E501
        if 'unfinished' in local_var_params and local_var_params['unfinished'] is not None:  # noqa: E501
            query_params.append(('unfinished', local_var_params['unfinished']))  # noqa: E501
        if 'canceled' in local_var_params and local_var_params['canceled'] is not None:  # noqa: E501
            query_params.append(('canceled', local_var_params['canceled']))  # noqa: E501
        if 'complete_scope' in local_var_params and local_var_params['complete_scope'] is not None:  # noqa: E501
            query_params.append(('completeScope', local_var_params['complete_scope']))  # noqa: E501
        if 'started_before' in local_var_params and local_var_params['started_before'] is not None:  # noqa: E501
            query_params.append(('startedBefore', local_var_params['started_before']))  # noqa: E501
        if 'started_after' in local_var_params and local_var_params['started_after'] is not None:  # noqa: E501
            query_params.append(('startedAfter', local_var_params['started_after']))  # noqa: E501
        if 'finished_before' in local_var_params and local_var_params['finished_before'] is not None:  # noqa: E501
            query_params.append(('finishedBefore', local_var_params['finished_before']))  # noqa: E501
        if 'finished_after' in local_var_params and local_var_params['finished_after'] is not None:  # noqa: E501
            query_params.append(('finishedAfter', local_var_params['finished_after']))  # noqa: E501
        if 'tenant_id_in' in local_var_params and local_var_params['tenant_id_in'] is not None:  # noqa: E501
            query_params.append(('tenantIdIn', local_var_params['tenant_id_in']))  # noqa: E501
        if 'without_tenant_id' in local_var_params and local_var_params['without_tenant_id'] is not None:  # noqa: E501
            query_params.append(('withoutTenantId', local_var_params['without_tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/history/activity-instance/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_historic_activity_instances(self, **kwargs):  # noqa: E501
        """Get List (POST)  # noqa: E501

        Queries for historic activity instances that fulfill the given parameters. The size of the result set can be retrieved by using the [Get Historic Activity Instance Count](https://docs.camunda.org/manual/7.14/reference/rest/history/activity-instance/get-activity-instance-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_historic_activity_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param HistoricActivityInstanceQueryDto historic_activity_instance_query_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[HistoricActivityInstanceDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.query_historic_activity_instances_with_http_info(**kwargs)  # noqa: E501

    def query_historic_activity_instances_with_http_info(self, **kwargs):  # noqa: E501
        """Get List (POST)  # noqa: E501

        Queries for historic activity instances that fulfill the given parameters. The size of the result set can be retrieved by using the [Get Historic Activity Instance Count](https://docs.camunda.org/manual/7.14/reference/rest/history/activity-instance/get-activity-instance-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_historic_activity_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param HistoricActivityInstanceQueryDto historic_activity_instance_query_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[HistoricActivityInstanceDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'first_result',
            'max_results',
            'historic_activity_instance_query_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_historic_activity_instances" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first_result' in local_var_params and local_var_params['first_result'] is not None:  # noqa: E501
            query_params.append(('firstResult', local_var_params['first_result']))  # noqa: E501
        if 'max_results' in local_var_params and local_var_params['max_results'] is not None:  # noqa: E501
            query_params.append(('maxResults', local_var_params['max_results']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'historic_activity_instance_query_dto' in local_var_params:
            body_params = local_var_params['historic_activity_instance_query_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/history/activity-instance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[HistoricActivityInstanceDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_historic_activity_instances_count(self, **kwargs):  # noqa: E501
        """Get List Count (POST)  # noqa: E501

        Queries for the number of historic activity instances that fulfill the given parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_historic_activity_instances_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param HistoricActivityInstanceQueryDto historic_activity_instance_query_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CountResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.query_historic_activity_instances_count_with_http_info(**kwargs)  # noqa: E501

    def query_historic_activity_instances_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get List Count (POST)  # noqa: E501

        Queries for the number of historic activity instances that fulfill the given parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_historic_activity_instances_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param HistoricActivityInstanceQueryDto historic_activity_instance_query_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CountResultDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'historic_activity_instance_query_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_historic_activity_instances_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'historic_activity_instance_query_dto' in local_var_params:
            body_params = local_var_params['historic_activity_instance_query_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/history/activity-instance/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class VariableValueDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'value': 'object',
        'type': 'str',
        'value_info': 'dict(str, object)'
    }

    attribute_map = {
        'value': 'value',
        'type': 'type',
        'value_info': 'valueInfo'
    }

    def __init__(self, value=None, type=None, value_info=None, local_vars_configuration=None):  # noqa: E501
        """VariableValueDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._value = None
        self._type = None
        self._value_info = None
        self.discriminator = None

        if value is not None:
            self.value = value
        if type is not None:
            self.type = type
        if value_info is not None:
            self.value_info = value_info

    @property
    def value(self):
        """Gets the value of this VariableValueDto.  # noqa: E501

        The variable's value. Value differs depending on the variable's type and on the deserializeValues parameter.  # noqa: E501

        :return: The value of this VariableValueDto.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this VariableValueDto.

        The variable's value. Value differs depending on the variable's type and on the deserializeValues parameter.  # noqa: E501

        :param value: The value of this VariableValueDto.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def type(self):
        """Gets the type of this VariableValueDto.  # noqa: E501

        The value type of the variable.  # noqa: E501

        :return: The type of this VariableValueDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this VariableValueDto.

        The value type of the variable.  # noqa: E501

        :param type: The type of this VariableValueDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def value_info(self):
        """Gets the value_info of this VariableValueDto.  # noqa: E501

        A JSON object containing additional, value-type-dependent properties. For serialized variables of type Object, the following properties can be provided:  * `objectTypeName`: A string representation of the object's type name. * `serializationDataFormat`: The serialization format used to store the variable.  For serialized variables of type File, the following properties can be provided:  * `filename`: The name of the file. This is not the variable name but the name that will be used when downloading the file again. * `mimetype`: The MIME type of the file that is being uploaded. * `encoding`: The encoding of the file that is being uploaded.  # noqa: E501

        :return: The value_info of this VariableValueDto.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._value_info

    @value_info.setter
    def value_info(self, value_info):
        """Sets the value_info of this VariableValueDto.

        A JSON object containing additional, value-type-dependent properties. For serialized variables of type Object, the following properties can be provided:  * `objectTypeName`: A string representation of the object's type name. * `serializationDataFormat`: The serialization format used to store the variable.  For serialized variables of type File, the following properties can be provided:  * `filename`: The name of the file. This is not the variable name but the name that will be used when downloading the file again. * `mimetype`: The MIME type of the file that is being uploaded. * `encoding`: The encoding of the file that is being uploaded.  # noqa: E501

        :param value_info: The value_info of this VariableValueDto.  # noqa: E501
        :type: dict(str, object)
        """

        self._value_info = value_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VariableValueDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VariableValueDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.process_instance_modification_instruction_dto import ProcessInstanceModificationInstructionDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestProcessInstanceModificationInstructionDto(unittest.TestCase):
    """ProcessInstanceModificationInstructionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProcessInstanceModificationInstructionDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.process_instance_modification_instruction_dto.ProcessInstanceModificationInstructionDto()  # noqa: E501
        if include_optional :
            return ProcessInstanceModificationInstructionDto(
                type = 'cancel', 
                variables = null, 
                activity_id = '0', 
                transition_id = '0', 
                activity_instance_id = '0', 
                transition_instance_id = '0', 
                ancestor_activity_instance_id = '0', 
                cancel_current_active_activity_instances = True
            )
        else :
            return ProcessInstanceModificationInstructionDto(
                type = 'cancel',
        )

    def testProcessInstanceModificationInstructionDto(self):
        """Test ProcessInstanceModificationInstructionDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class FetchExternalTasksDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'worker_id': 'str',
        'max_tasks': 'int',
        'use_priority': 'bool',
        'async_response_timeout': 'int',
        'topics': 'list[FetchExternalTaskTopicDto]'
    }

    attribute_map = {
        'worker_id': 'workerId',
        'max_tasks': 'maxTasks',
        'use_priority': 'usePriority',
        'async_response_timeout': 'asyncResponseTimeout',
        'topics': 'topics'
    }

    def __init__(self, worker_id=None, max_tasks=None, use_priority=None, async_response_timeout=None, topics=None, local_vars_configuration=None):  # noqa: E501
        """FetchExternalTasksDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._worker_id = None
        self._max_tasks = None
        self._use_priority = None
        self._async_response_timeout = None
        self._topics = None
        self.discriminator = None

        self.worker_id = worker_id
        self.max_tasks = max_tasks
        self.use_priority = use_priority
        self.async_response_timeout = async_response_timeout
        if topics is not None:
            self.topics = topics

    @property
    def worker_id(self):
        """Gets the worker_id of this FetchExternalTasksDto.  # noqa: E501

        **Mandatory.** The id of the worker on which behalf tasks are fetched. The returned tasks are locked for that worker and can only be completed when providing the same worker id.  # noqa: E501

        :return: The worker_id of this FetchExternalTasksDto.  # noqa: E501
        :rtype: str
        """
        return self._worker_id

    @worker_id.setter
    def worker_id(self, worker_id):
        """Sets the worker_id of this FetchExternalTasksDto.

        **Mandatory.** The id of the worker on which behalf tasks are fetched. The returned tasks are locked for that worker and can only be completed when providing the same worker id.  # noqa: E501

        :param worker_id: The worker_id of this FetchExternalTasksDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and worker_id is None:  # noqa: E501
            raise ValueError("Invalid value for `worker_id`, must not be `None`")  # noqa: E501

        self._worker_id = worker_id

    @property
    def max_tasks(self):
        """Gets the max_tasks of this FetchExternalTasksDto.  # noqa: E501

        **Mandatory.** The maximum number of tasks to return.  # noqa: E501

        :return: The max_tasks of this FetchExternalTasksDto.  # noqa: E501
        :rtype: int
        """
        return self._max_tasks

    @max_tasks.setter
    def max_tasks(self, max_tasks):
        """Sets the max_tasks of this FetchExternalTasksDto.

        **Mandatory.** The maximum number of tasks to return.  # noqa: E501

        :param max_tasks: The max_tasks of this FetchExternalTasksDto.  # noqa: E501
        :type: int
        """

        self._max_tasks = max_tasks

    @property
    def use_priority(self):
        """Gets the use_priority of this FetchExternalTasksDto.  # noqa: E501

        A `boolean` value, which indicates whether the task should be fetched based on its priority or arbitrarily.  # noqa: E501

        :return: The use_priority of this FetchExternalTasksDto.  # noqa: E501
        :rtype: bool
        """
        return self._use_priority

    @use_priority.setter
    def use_priority(self, use_priority):
        """Sets the use_priority of this FetchExternalTasksDto.

        A `boolean` value, which indicates whether the task should be fetched based on its priority or arbitrarily.  # noqa: E501

        :param use_priority: The use_priority of this FetchExternalTasksDto.  # noqa: E501
        :type: bool
        """

        self._use_priority = use_priority

    @property
    def async_response_timeout(self):
        """Gets the async_response_timeout of this FetchExternalTasksDto.  # noqa: E501

        The [Long Polling](https://docs.camunda.org/manual/7.14/user-guide/process-engine/external-tasks/#long-polling-to-fetch-and-lock-external-tasks) timeout in milliseconds.  **Note:** The value cannot be set larger than 1.800.000 milliseconds (corresponds to 30 minutes).  # noqa: E501

        :return: The async_response_timeout of this FetchExternalTasksDto.  # noqa: E501
        :rtype: int
        """
        return self._async_response_timeout

    @async_response_timeout.setter
    def async_response_timeout(self, async_response_timeout):
        """Sets the async_response_timeout of this FetchExternalTasksDto.

        The [Long Polling](https://docs.camunda.org/manual/7.14/user-guide/process-engine/external-tasks/#long-polling-to-fetch-and-lock-external-tasks) timeout in milliseconds.  **Note:** The value cannot be set larger than 1.800.000 milliseconds (corresponds to 30 minutes).  # noqa: E501

        :param async_response_timeout: The async_response_timeout of this FetchExternalTasksDto.  # noqa: E501
        :type: int
        """

        self._async_response_timeout = async_response_timeout

    @property
    def topics(self):
        """Gets the topics of this FetchExternalTasksDto.  # noqa: E501

        A JSON array of topic objects for which external tasks should be fetched. The returned tasks may be arbitrarily distributed among these topics. Each topic object has the following properties:  # noqa: E501

        :return: The topics of this FetchExternalTasksDto.  # noqa: E501
        :rtype: list[FetchExternalTaskTopicDto]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        """Sets the topics of this FetchExternalTasksDto.

        A JSON array of topic objects for which external tasks should be fetched. The returned tasks may be arbitrarily distributed among these topics. Each topic object has the following properties:  # noqa: E501

        :param topics: The topics of this FetchExternalTasksDto.  # noqa: E501
        :type: list[FetchExternalTaskTopicDto]
        """

        self._topics = topics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FetchExternalTasksDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FetchExternalTasksDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.process_definition_statistics_result_dto import ProcessDefinitionStatisticsResultDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestProcessDefinitionStatisticsResultDto(unittest.TestCase):
    """ProcessDefinitionStatisticsResultDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProcessDefinitionStatisticsResultDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.process_definition_statistics_result_dto.ProcessDefinitionStatisticsResultDto()  # noqa: E501
        if include_optional :
            return ProcessDefinitionStatisticsResultDto(
                id = '0', 
                instances = 56, 
                failed_jobs = 56, 
                incidents = [
                    generic_camunda_client.models.incident_statistics_result_dto.IncidentStatisticsResultDto(
                        incident_type = '0', 
                        incident_count = 56, )
                    ], 
                definition = generic_camunda_client.models.process_definition_dto.ProcessDefinitionDto(
                    id = '0', 
                    key = '0', 
                    category = '0', 
                    description = '0', 
                    name = '0', 
                    version = 56, 
                    resource = '0', 
                    deployment_id = '0', 
                    diagram = '0', 
                    suspended = True, 
                    tenant_id = '0', 
                    version_tag = '0', 
                    history_time_to_live = 0, 
                    startable_in_tasklist = True, )
            )
        else :
            return ProcessDefinitionStatisticsResultDto(
        )

    def testProcessDefinitionStatisticsResultDto(self):
        """Test ProcessDefinitionStatisticsResultDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProcessInstanceModificationInstructionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'variables': 'TriggerVariableValueDto',
        'activity_id': 'str',
        'transition_id': 'str',
        'activity_instance_id': 'str',
        'transition_instance_id': 'str',
        'ancestor_activity_instance_id': 'str',
        'cancel_current_active_activity_instances': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'variables': 'variables',
        'activity_id': 'activityId',
        'transition_id': 'transitionId',
        'activity_instance_id': 'activityInstanceId',
        'transition_instance_id': 'transitionInstanceId',
        'ancestor_activity_instance_id': 'ancestorActivityInstanceId',
        'cancel_current_active_activity_instances': 'cancelCurrentActiveActivityInstances'
    }

    def __init__(self, type=None, variables=None, activity_id=None, transition_id=None, activity_instance_id=None, transition_instance_id=None, ancestor_activity_instance_id=None, cancel_current_active_activity_instances=None, local_vars_configuration=None):  # noqa: E501
        """ProcessInstanceModificationInstructionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._variables = None
        self._activity_id = None
        self._transition_id = None
        self._activity_instance_id = None
        self._transition_instance_id = None
        self._ancestor_activity_instance_id = None
        self._cancel_current_active_activity_instances = None
        self.discriminator = None

        self.type = type
        if variables is not None:
            self.variables = variables
        if activity_id is not None:
            self.activity_id = activity_id
        if transition_id is not None:
            self.transition_id = transition_id
        if activity_instance_id is not None:
            self.activity_instance_id = activity_instance_id
        if transition_instance_id is not None:
            self.transition_instance_id = transition_instance_id
        if ancestor_activity_instance_id is not None:
            self.ancestor_activity_instance_id = ancestor_activity_instance_id
        self.cancel_current_active_activity_instances = cancel_current_active_activity_instances

    @property
    def type(self):
        """Gets the type of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        **Mandatory**. One of the following values: `cancel`, `startBeforeActivity`, `startAfterActivity`, `startTransition`.  * A cancel instruction requests cancellation of a single activity instance or all instances of one activity. * A startBeforeActivity instruction requests to enter a given activity. * A startAfterActivity instruction requests to execute the single outgoing sequence flow of a given activity. * A startTransition instruction requests to execute a specific sequence flow.  # noqa: E501

        :return: The type of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ProcessInstanceModificationInstructionDto.

        **Mandatory**. One of the following values: `cancel`, `startBeforeActivity`, `startAfterActivity`, `startTransition`.  * A cancel instruction requests cancellation of a single activity instance or all instances of one activity. * A startBeforeActivity instruction requests to enter a given activity. * A startAfterActivity instruction requests to execute the single outgoing sequence flow of a given activity. * A startTransition instruction requests to execute a specific sequence flow.  # noqa: E501

        :param type: The type of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["cancel", "startBeforeActivity", "startAfterActivity", "startTransition"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def variables(self):
        """Gets the variables of this ProcessInstanceModificationInstructionDto.  # noqa: E501


        :return: The variables of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: TriggerVariableValueDto
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this ProcessInstanceModificationInstructionDto.


        :param variables: The variables of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: TriggerVariableValueDto
        """

        self._variables = variables

    @property
    def activity_id(self):
        """Gets the activity_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        Can be used with instructions of types `startTransition`. Specifies the sequence flow to start.  # noqa: E501

        :return: The activity_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this ProcessInstanceModificationInstructionDto.

        Can be used with instructions of types `startTransition`. Specifies the sequence flow to start.  # noqa: E501

        :param activity_id: The activity_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def transition_id(self):
        """Gets the transition_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        Can be used with instructions of types `startTransition`. Specifies the sequence flow to start.  # noqa: E501

        :return: The transition_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: str
        """
        return self._transition_id

    @transition_id.setter
    def transition_id(self, transition_id):
        """Sets the transition_id of this ProcessInstanceModificationInstructionDto.

        Can be used with instructions of types `startTransition`. Specifies the sequence flow to start.  # noqa: E501

        :param transition_id: The transition_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: str
        """

        self._transition_id = transition_id

    @property
    def activity_instance_id(self):
        """Gets the activity_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        Can be used with instructions of type `cancel`. Specifies the activity instance to cancel. Valid values are the activity instance IDs supplied by the [Get Activity Instance request](https://docs.camunda.org/manual/7.14/reference/rest/process-instance/get-activity-instances/).  # noqa: E501

        :return: The activity_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_instance_id

    @activity_instance_id.setter
    def activity_instance_id(self, activity_instance_id):
        """Sets the activity_instance_id of this ProcessInstanceModificationInstructionDto.

        Can be used with instructions of type `cancel`. Specifies the activity instance to cancel. Valid values are the activity instance IDs supplied by the [Get Activity Instance request](https://docs.camunda.org/manual/7.14/reference/rest/process-instance/get-activity-instances/).  # noqa: E501

        :param activity_instance_id: The activity_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: str
        """

        self._activity_instance_id = activity_instance_id

    @property
    def transition_instance_id(self):
        """Gets the transition_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        Can be used with instructions of type `cancel`. Specifies the transition instance to cancel. Valid values are the transition instance IDs supplied by the [Get Activity Instance request](https://docs.camunda.org/manual/7.14/reference/rest/process-instance/get-activity-instances/).  # noqa: E501

        :return: The transition_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: str
        """
        return self._transition_instance_id

    @transition_instance_id.setter
    def transition_instance_id(self, transition_instance_id):
        """Sets the transition_instance_id of this ProcessInstanceModificationInstructionDto.

        Can be used with instructions of type `cancel`. Specifies the transition instance to cancel. Valid values are the transition instance IDs supplied by the [Get Activity Instance request](https://docs.camunda.org/manual/7.14/reference/rest/process-instance/get-activity-instances/).  # noqa: E501

        :param transition_instance_id: The transition_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: str
        """

        self._transition_instance_id = transition_instance_id

    @property
    def ancestor_activity_instance_id(self):
        """Gets the ancestor_activity_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        Can be used with instructions of type `startBeforeActivity`, `startAfterActivity`, and `startTransition`. Valid values are the activity instance IDs supplied by the Get Activity Instance request. If there are multiple parent activity instances of the targeted activity, this specifies the ancestor scope in which hierarchy the activity/transition is to be instantiated.  Example: When there are two instances of a subprocess and an activity contained in the subprocess is to be started, this parameter allows to specifiy under which subprocess instance the activity should be started.  # noqa: E501

        :return: The ancestor_activity_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: str
        """
        return self._ancestor_activity_instance_id

    @ancestor_activity_instance_id.setter
    def ancestor_activity_instance_id(self, ancestor_activity_instance_id):
        """Sets the ancestor_activity_instance_id of this ProcessInstanceModificationInstructionDto.

        Can be used with instructions of type `startBeforeActivity`, `startAfterActivity`, and `startTransition`. Valid values are the activity instance IDs supplied by the Get Activity Instance request. If there are multiple parent activity instances of the targeted activity, this specifies the ancestor scope in which hierarchy the activity/transition is to be instantiated.  Example: When there are two instances of a subprocess and an activity contained in the subprocess is to be started, this parameter allows to specifiy under which subprocess instance the activity should be started.  # noqa: E501

        :param ancestor_activity_instance_id: The ancestor_activity_instance_id of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: str
        """

        self._ancestor_activity_instance_id = ancestor_activity_instance_id

    @property
    def cancel_current_active_activity_instances(self):
        """Gets the cancel_current_active_activity_instances of this ProcessInstanceModificationInstructionDto.  # noqa: E501

        Can be used with instructions of type cancel. Prevents the deletion of new created activity instances.  # noqa: E501

        :return: The cancel_current_active_activity_instances of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :rtype: bool
        """
        return self._cancel_current_active_activity_instances

    @cancel_current_active_activity_instances.setter
    def cancel_current_active_activity_instances(self, cancel_current_active_activity_instances):
        """Sets the cancel_current_active_activity_instances of this ProcessInstanceModificationInstructionDto.

        Can be used with instructions of type cancel. Prevents the deletion of new created activity instances.  # noqa: E501

        :param cancel_current_active_activity_instances: The cancel_current_active_activity_instances of this ProcessInstanceModificationInstructionDto.  # noqa: E501
        :type: bool
        """

        self._cancel_current_active_activity_instances = cancel_current_active_activity_instances

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessInstanceModificationInstructionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessInstanceModificationInstructionDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ExternalTaskQueryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'external_task_id': 'str',
        'external_task_id_in': 'list[str]',
        'topic_name': 'str',
        'worker_id': 'str',
        'locked': 'bool',
        'not_locked': 'bool',
        'with_retries_left': 'bool',
        'no_retries_left': 'bool',
        'lock_expiration_after': 'datetime',
        'lock_expiration_before': 'datetime',
        'activity_id': 'str',
        'activity_id_in': 'list[str]',
        'execution_id': 'str',
        'process_instance_id': 'str',
        'process_instance_id_in': 'list[str]',
        'process_definition_id': 'str',
        'tenant_id_in': 'list[str]',
        'active': 'bool',
        'suspended': 'bool',
        'priority_higher_than_or_equals': 'int',
        'priority_lower_than_or_equals': 'int',
        'sorting': 'list[ExternalTaskQueryDtoSorting]'
    }

    attribute_map = {
        'external_task_id': 'externalTaskId',
        'external_task_id_in': 'externalTaskIdIn',
        'topic_name': 'topicName',
        'worker_id': 'workerId',
        'locked': 'locked',
        'not_locked': 'notLocked',
        'with_retries_left': 'withRetriesLeft',
        'no_retries_left': 'noRetriesLeft',
        'lock_expiration_after': 'lockExpirationAfter',
        'lock_expiration_before': 'lockExpirationBefore',
        'activity_id': 'activityId',
        'activity_id_in': 'activityIdIn',
        'execution_id': 'executionId',
        'process_instance_id': 'processInstanceId',
        'process_instance_id_in': 'processInstanceIdIn',
        'process_definition_id': 'processDefinitionId',
        'tenant_id_in': 'tenantIdIn',
        'active': 'active',
        'suspended': 'suspended',
        'priority_higher_than_or_equals': 'priorityHigherThanOrEquals',
        'priority_lower_than_or_equals': 'priorityLowerThanOrEquals',
        'sorting': 'sorting'
    }

    def __init__(self, external_task_id=None, external_task_id_in=None, topic_name=None, worker_id=None, locked=None, not_locked=None, with_retries_left=None, no_retries_left=None, lock_expiration_after=None, lock_expiration_before=None, activity_id=None, activity_id_in=None, execution_id=None, process_instance_id=None, process_instance_id_in=None, process_definition_id=None, tenant_id_in=None, active=None, suspended=None, priority_higher_than_or_equals=None, priority_lower_than_or_equals=None, sorting=None, local_vars_configuration=None):  # noqa: E501
        """ExternalTaskQueryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._external_task_id = None
        self._external_task_id_in = None
        self._topic_name = None
        self._worker_id = None
        self._locked = None
        self._not_locked = None
        self._with_retries_left = None
        self._no_retries_left = None
        self._lock_expiration_after = None
        self._lock_expiration_before = None
        self._activity_id = None
        self._activity_id_in = None
        self._execution_id = None
        self._process_instance_id = None
        self._process_instance_id_in = None
        self._process_definition_id = None
        self._tenant_id_in = None
        self._active = None
        self._suspended = None
        self._priority_higher_than_or_equals = None
        self._priority_lower_than_or_equals = None
        self._sorting = None
        self.discriminator = None

        if external_task_id is not None:
            self.external_task_id = external_task_id
        if external_task_id_in is not None:
            self.external_task_id_in = external_task_id_in
        if topic_name is not None:
            self.topic_name = topic_name
        if worker_id is not None:
            self.worker_id = worker_id
        self.locked = locked
        self.not_locked = not_locked
        self.with_retries_left = with_retries_left
        self.no_retries_left = no_retries_left
        self.lock_expiration_after = lock_expiration_after
        self.lock_expiration_before = lock_expiration_before
        if activity_id is not None:
            self.activity_id = activity_id
        if activity_id_in is not None:
            self.activity_id_in = activity_id_in
        if execution_id is not None:
            self.execution_id = execution_id
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if process_instance_id_in is not None:
            self.process_instance_id_in = process_instance_id_in
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if tenant_id_in is not None:
            self.tenant_id_in = tenant_id_in
        self.active = active
        self.suspended = suspended
        self.priority_higher_than_or_equals = priority_higher_than_or_equals
        self.priority_lower_than_or_equals = priority_lower_than_or_equals
        if sorting is not None:
            self.sorting = sorting

    @property
    def external_task_id(self):
        """Gets the external_task_id of this ExternalTaskQueryDto.  # noqa: E501

        Filter by an external task's id.  # noqa: E501

        :return: The external_task_id of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._external_task_id

    @external_task_id.setter
    def external_task_id(self, external_task_id):
        """Sets the external_task_id of this ExternalTaskQueryDto.

        Filter by an external task's id.  # noqa: E501

        :param external_task_id: The external_task_id of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._external_task_id = external_task_id

    @property
    def external_task_id_in(self):
        """Gets the external_task_id_in of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the comma-separated list of external task ids.  # noqa: E501

        :return: The external_task_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._external_task_id_in

    @external_task_id_in.setter
    def external_task_id_in(self, external_task_id_in):
        """Sets the external_task_id_in of this ExternalTaskQueryDto.

        Filter by the comma-separated list of external task ids.  # noqa: E501

        :param external_task_id_in: The external_task_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._external_task_id_in = external_task_id_in

    @property
    def topic_name(self):
        """Gets the topic_name of this ExternalTaskQueryDto.  # noqa: E501

        Filter by an external task topic.  # noqa: E501

        :return: The topic_name of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._topic_name

    @topic_name.setter
    def topic_name(self, topic_name):
        """Sets the topic_name of this ExternalTaskQueryDto.

        Filter by an external task topic.  # noqa: E501

        :param topic_name: The topic_name of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._topic_name = topic_name

    @property
    def worker_id(self):
        """Gets the worker_id of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the id of the worker that the task was most recently locked by.  # noqa: E501

        :return: The worker_id of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._worker_id

    @worker_id.setter
    def worker_id(self, worker_id):
        """Sets the worker_id of this ExternalTaskQueryDto.

        Filter by the id of the worker that the task was most recently locked by.  # noqa: E501

        :param worker_id: The worker_id of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._worker_id = worker_id

    @property
    def locked(self):
        """Gets the locked of this ExternalTaskQueryDto.  # noqa: E501

        Only include external tasks that are currently locked (i.e., they have a lock time and it has not expired). Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :return: The locked of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this ExternalTaskQueryDto.

        Only include external tasks that are currently locked (i.e., they have a lock time and it has not expired). Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :param locked: The locked of this ExternalTaskQueryDto.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def not_locked(self):
        """Gets the not_locked of this ExternalTaskQueryDto.  # noqa: E501

        Only include external tasks that are currently not locked (i.e., they have no lock or it has expired). Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :return: The not_locked of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._not_locked

    @not_locked.setter
    def not_locked(self, not_locked):
        """Sets the not_locked of this ExternalTaskQueryDto.

        Only include external tasks that are currently not locked (i.e., they have no lock or it has expired). Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :param not_locked: The not_locked of this ExternalTaskQueryDto.  # noqa: E501
        :type: bool
        """

        self._not_locked = not_locked

    @property
    def with_retries_left(self):
        """Gets the with_retries_left of this ExternalTaskQueryDto.  # noqa: E501

        Only include external tasks that have a positive (&gt; 0) number of retries (or `null`). Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :return: The with_retries_left of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._with_retries_left

    @with_retries_left.setter
    def with_retries_left(self, with_retries_left):
        """Sets the with_retries_left of this ExternalTaskQueryDto.

        Only include external tasks that have a positive (&gt; 0) number of retries (or `null`). Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :param with_retries_left: The with_retries_left of this ExternalTaskQueryDto.  # noqa: E501
        :type: bool
        """

        self._with_retries_left = with_retries_left

    @property
    def no_retries_left(self):
        """Gets the no_retries_left of this ExternalTaskQueryDto.  # noqa: E501

        Only include external tasks that have 0 retries. Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :return: The no_retries_left of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._no_retries_left

    @no_retries_left.setter
    def no_retries_left(self, no_retries_left):
        """Sets the no_retries_left of this ExternalTaskQueryDto.

        Only include external tasks that have 0 retries. Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :param no_retries_left: The no_retries_left of this ExternalTaskQueryDto.  # noqa: E501
        :type: bool
        """

        self._no_retries_left = no_retries_left

    @property
    def lock_expiration_after(self):
        """Gets the lock_expiration_after of this ExternalTaskQueryDto.  # noqa: E501

        Restrict to external tasks that have a lock that expires after a given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The lock_expiration_after of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._lock_expiration_after

    @lock_expiration_after.setter
    def lock_expiration_after(self, lock_expiration_after):
        """Sets the lock_expiration_after of this ExternalTaskQueryDto.

        Restrict to external tasks that have a lock that expires after a given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param lock_expiration_after: The lock_expiration_after of this ExternalTaskQueryDto.  # noqa: E501
        :type: datetime
        """

        self._lock_expiration_after = lock_expiration_after

    @property
    def lock_expiration_before(self):
        """Gets the lock_expiration_before of this ExternalTaskQueryDto.  # noqa: E501

        Restrict to external tasks that have a lock that expires before a given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The lock_expiration_before of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._lock_expiration_before

    @lock_expiration_before.setter
    def lock_expiration_before(self, lock_expiration_before):
        """Sets the lock_expiration_before of this ExternalTaskQueryDto.

        Restrict to external tasks that have a lock that expires before a given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param lock_expiration_before: The lock_expiration_before of this ExternalTaskQueryDto.  # noqa: E501
        :type: datetime
        """

        self._lock_expiration_before = lock_expiration_before

    @property
    def activity_id(self):
        """Gets the activity_id of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the id of the activity that an external task is created for.  # noqa: E501

        :return: The activity_id of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this ExternalTaskQueryDto.

        Filter by the id of the activity that an external task is created for.  # noqa: E501

        :param activity_id: The activity_id of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def activity_id_in(self):
        """Gets the activity_id_in of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the comma-separated list of ids of the activities that an external task is created for.  # noqa: E501

        :return: The activity_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._activity_id_in

    @activity_id_in.setter
    def activity_id_in(self, activity_id_in):
        """Sets the activity_id_in of this ExternalTaskQueryDto.

        Filter by the comma-separated list of ids of the activities that an external task is created for.  # noqa: E501

        :param activity_id_in: The activity_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._activity_id_in = activity_id_in

    @property
    def execution_id(self):
        """Gets the execution_id of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the id of the execution that an external task belongs to.  # noqa: E501

        :return: The execution_id of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this ExternalTaskQueryDto.

        Filter by the id of the execution that an external task belongs to.  # noqa: E501

        :param execution_id: The execution_id of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the id of the process instance that an external task belongs to.  # noqa: E501

        :return: The process_instance_id of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this ExternalTaskQueryDto.

        Filter by the id of the process instance that an external task belongs to.  # noqa: E501

        :param process_instance_id: The process_instance_id of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def process_instance_id_in(self):
        """Gets the process_instance_id_in of this ExternalTaskQueryDto.  # noqa: E501

        Filter by a comma-separated list of process instance ids that an external task may belong to.  # noqa: E501

        :return: The process_instance_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_instance_id_in

    @process_instance_id_in.setter
    def process_instance_id_in(self, process_instance_id_in):
        """Sets the process_instance_id_in of this ExternalTaskQueryDto.

        Filter by a comma-separated list of process instance ids that an external task may belong to.  # noqa: E501

        :param process_instance_id_in: The process_instance_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._process_instance_id_in = process_instance_id_in

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this ExternalTaskQueryDto.  # noqa: E501

        Filter by the id of the process definition that an external task belongs to.  # noqa: E501

        :return: The process_definition_id of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this ExternalTaskQueryDto.

        Filter by the id of the process definition that an external task belongs to.  # noqa: E501

        :param process_definition_id: The process_definition_id of this ExternalTaskQueryDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def tenant_id_in(self):
        """Gets the tenant_id_in of this ExternalTaskQueryDto.  # noqa: E501

        Filter by a comma-separated list of tenant ids. An external task must have one of the given tenant ids.  # noqa: E501

        :return: The tenant_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._tenant_id_in

    @tenant_id_in.setter
    def tenant_id_in(self, tenant_id_in):
        """Sets the tenant_id_in of this ExternalTaskQueryDto.

        Filter by a comma-separated list of tenant ids. An external task must have one of the given tenant ids.  # noqa: E501

        :param tenant_id_in: The tenant_id_in of this ExternalTaskQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._tenant_id_in = tenant_id_in

    @property
    def active(self):
        """Gets the active of this ExternalTaskQueryDto.  # noqa: E501

        Only include active tasks. Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :return: The active of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this ExternalTaskQueryDto.

        Only include active tasks. Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :param active: The active of this ExternalTaskQueryDto.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def suspended(self):
        """Gets the suspended of this ExternalTaskQueryDto.  # noqa: E501

        Only include suspended tasks. Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :return: The suspended of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this ExternalTaskQueryDto.

        Only include suspended tasks. Value may only be `true`, as `false` matches any external task.  # noqa: E501

        :param suspended: The suspended of this ExternalTaskQueryDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def priority_higher_than_or_equals(self):
        """Gets the priority_higher_than_or_equals of this ExternalTaskQueryDto.  # noqa: E501

        Only include jobs with a priority higher than or equal to the given value. Value must be a valid `long` value.  # noqa: E501

        :return: The priority_higher_than_or_equals of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: int
        """
        return self._priority_higher_than_or_equals

    @priority_higher_than_or_equals.setter
    def priority_higher_than_or_equals(self, priority_higher_than_or_equals):
        """Sets the priority_higher_than_or_equals of this ExternalTaskQueryDto.

        Only include jobs with a priority higher than or equal to the given value. Value must be a valid `long` value.  # noqa: E501

        :param priority_higher_than_or_equals: The priority_higher_than_or_equals of this ExternalTaskQueryDto.  # noqa: E501
        :type: int
        """

        self._priority_higher_than_or_equals = priority_higher_than_or_equals

    @property
    def priority_lower_than_or_equals(self):
        """Gets the priority_lower_than_or_equals of this ExternalTaskQueryDto.  # noqa: E501

        Only include jobs with a priority lower than or equal to the given value. Value must be a valid `long` value.  # noqa: E501

        :return: The priority_lower_than_or_equals of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: int
        """
        return self._priority_lower_than_or_equals

    @priority_lower_than_or_equals.setter
    def priority_lower_than_or_equals(self, priority_lower_than_or_equals):
        """Sets the priority_lower_than_or_equals of this ExternalTaskQueryDto.

        Only include jobs with a priority lower than or equal to the given value. Value must be a valid `long` value.  # noqa: E501

        :param priority_lower_than_or_equals: The priority_lower_than_or_equals of this ExternalTaskQueryDto.  # noqa: E501
        :type: int
        """

        self._priority_lower_than_or_equals = priority_lower_than_or_equals

    @property
    def sorting(self):
        """Gets the sorting of this ExternalTaskQueryDto.  # noqa: E501

        A JSON array of criteria to sort the result by. Each element of the array is a JSON object that                     specifies one ordering. The position in the array identifies the rank of an ordering, i.e., whether                     it is primary, secondary, etc. The ordering objects have the following properties:                      **Note:** The `sorting` properties will not be applied to the External Task count query.  # noqa: E501

        :return: The sorting of this ExternalTaskQueryDto.  # noqa: E501
        :rtype: list[ExternalTaskQueryDtoSorting]
        """
        return self._sorting

    @sorting.setter
    def sorting(self, sorting):
        """Sets the sorting of this ExternalTaskQueryDto.

        A JSON array of criteria to sort the result by. Each element of the array is a JSON object that                     specifies one ordering. The position in the array identifies the rank of an ordering, i.e., whether                     it is primary, secondary, etc. The ordering objects have the following properties:                      **Note:** The `sorting` properties will not be applied to the External Task count query.  # noqa: E501

        :param sorting: The sorting of this ExternalTaskQueryDto.  # noqa: E501
        :type: list[ExternalTaskQueryDtoSorting]
        """

        self._sorting = sorting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalTaskQueryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExternalTaskQueryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class MultiFormVariableBinaryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'data': 'file',
        'value_type': 'str'
    }

    attribute_map = {
        'data': 'data',
        'value_type': 'valueType'
    }

    def __init__(self, data=None, value_type=None, local_vars_configuration=None):  # noqa: E501
        """MultiFormVariableBinaryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._data = None
        self._value_type = None
        self.discriminator = None

        self.data = data
        if value_type is not None:
            self.value_type = value_type

    @property
    def data(self):
        """Gets the data of this MultiFormVariableBinaryDto.  # noqa: E501

        The binary data to be set. For File variables, this multipart can contain the filename, binary value and MIME type of the file variable to be set Only the filename is mandatory.  # noqa: E501

        :return: The data of this MultiFormVariableBinaryDto.  # noqa: E501
        :rtype: file
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this MultiFormVariableBinaryDto.

        The binary data to be set. For File variables, this multipart can contain the filename, binary value and MIME type of the file variable to be set Only the filename is mandatory.  # noqa: E501

        :param data: The data of this MultiFormVariableBinaryDto.  # noqa: E501
        :type: file
        """

        self._data = data

    @property
    def value_type(self):
        """Gets the value_type of this MultiFormVariableBinaryDto.  # noqa: E501

        The name of the variable type. Either Bytes for a byte array variable or File for a file variable.  # noqa: E501

        :return: The value_type of this MultiFormVariableBinaryDto.  # noqa: E501
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this MultiFormVariableBinaryDto.

        The name of the variable type. Either Bytes for a byte array variable or File for a file variable.  # noqa: E501

        :param value_type: The value_type of this MultiFormVariableBinaryDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["Bytes", "File"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and value_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `value_type` ({0}), must be one of {1}"  # noqa: E501
                .format(value_type, allowed_values)
            )

        self._value_type = value_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultiFormVariableBinaryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MultiFormVariableBinaryDto):
            return True

        return self.to_dict() != other.to_dict()
